=======
Credits
=======

* Special thanks to `Leonard Mandtler <https://github.com/LMandtler>`_ for providing a first prototype of a wordcloud mapping function and to `Julian Kath <https://github.com/juka19>`_ and `Lorenzo Gini <https://github.com/zazzooo>`_ for co-developing a working version of `WordCloud_Mapper in R <https://gabzech.github.io/wordcloud.mappeR>`_, which served as the basis for developing the first version of this package.
* The algorithm used to generate each individual wordcloud is built on top of `Andreas Mueller's wordcloud package <https://github.com/amueller/word_cloud>`_.
* The data on companies by country included in this package was obtained from the `2019 Global Company Dataset <https://www.peopledatalabs.com/company-dataset>`_ made freely available by People Data Labs.
* This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
